summaryrefslogtreecommitdiff
path: root/firmware/2lib/include/2api.h
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/2lib/include/2api.h')
-rw-r--r--firmware/2lib/include/2api.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/firmware/2lib/include/2api.h b/firmware/2lib/include/2api.h
index 9448e12a..94f0df5c 100644
--- a/firmware/2lib/include/2api.h
+++ b/firmware/2lib/include/2api.h
@@ -182,8 +182,12 @@ enum vb2_context_flags {
*/
VB2_CONTEXT_NVDATA_V2 = (1 << 18),
- /* Allow vendor data to be set via the vendor data ui. */
- VB2_CONTEXT_VENDOR_DATA_SETTABLE = (1 << 19),
+ /*
+ * Allow vendor data to be set via the vendor data ui.
+ *
+ * Deprecated with CL:2512740.
+ */
+ VB2_CONTEXT_DEPRECATED_VENDOR_DATA_SETTABLE = (1 << 19),
/*
* Caller may set this before running vb2api_fw_phase1. In this case,